pub struct AppArgs {
pub mailbox: bool,
pub port: Option<u16>,
pub data_dir: String,
pub encrypt: bool,
pub encryption_password: Option<String>,
pub web_port: Option<u16>,
}Expand description
Defines the command-line arguments for the application.
This struct is used by the clap crate to parse command-line arguments.
Fields
mailbox: boolIf set, the application will run in mailbox node mode.
port: Option<u16>The port to listen on. If not specified, a random free port will be used.
data_dir: StringThe directory where data will be stored.
encrypt: boolIf set, storage encryption will be enabled.
encryption_password: Option<String>The password to use for storage encryption.
This can also be set using the P2P_MESSENGER_PASSWORD environment variable.
web_port: Option<u16>The port for the Web UI. If not specified, a random free port will be used.
Implementations